summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2018-09-27 16:03:56 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2018-09-27 16:03:56 +0900
commita615469e90c89c23000bd7c2f2905744123ac728 (patch)
treee3db27e2ce51ea6c9cfb0bb7dc2256bf4f8e60f0
parentfe4b336173b34957c0ebaecaba3d8781623acb68 (diff)
downloadtdesdk-a615469e.tar.gz
tdesdk-a615469e.zip
qt -> tqt conversion:
QTDIR -> TQTDIR QTDOC -> TQTDOC INCDIR_QT -> INCDIR_TQT LIBDIR_QT -> LIBDIR_TQT QT_INC -> TQT_INC QT_LIB -> TQT_LIB Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
-rw-r--r--doc/scripts/man-qtdoc.1.docbook4
-rw-r--r--doc/scripts/tdesvn-build/index.docbook22
-rwxr-xr-xscripts/kde-build16
-rw-r--r--scripts/kde-buildrc2
-rw-r--r--scripts/kde-devel-vim.vim4
-rw-r--r--scripts/kde-emacs/kde-emacs-utils.el6
-rwxr-xr-xscripts/qtdoc10
-rwxr-xr-xscripts/tdesvn-build6
8 files changed, 35 insertions, 35 deletions
diff --git a/doc/scripts/man-qtdoc.1.docbook b/doc/scripts/man-qtdoc.1.docbook
index 7491089e..4924eb84 100644
--- a/doc/scripts/man-qtdoc.1.docbook
+++ b/doc/scripts/man-qtdoc.1.docbook
@@ -44,8 +44,8 @@ page for that class. Otherwise the main &Qt; help page is opened.
<variablelist>
<varlistentry>
-<term><envar>QTDIR</envar></term>
-<listitem><para>The directory beneath which &Qt; is installed. The main &Qt; help page is expected to be in <filename class="directory">$<envar>QTDIR</envar>/doc/html/</filename>.</para></listitem>
+<term><envar>TQTDIR</envar></term>
+<listitem><para>The directory beneath which &Qt; is installed. The main &Qt; help page is expected to be in <filename class="directory">$<envar>TQTDIR</envar>/doc/html/</filename>.</para></listitem>
</varlistentry>
</variablelist>
diff --git a/doc/scripts/tdesvn-build/index.docbook b/doc/scripts/tdesvn-build/index.docbook
index d9c58333..68c46659 100644
--- a/doc/scripts/tdesvn-build/index.docbook
+++ b/doc/scripts/tdesvn-build/index.docbook
@@ -256,7 +256,7 @@ and add to the end of the file:
<programlisting>
TDEDIR=(path to tdedir)
TDEDIRS=$TDEDIR
-PATH=$TDEDIR/bin:$QTDIR/bin:$PATH
+PATH=$TDEDIR/bin:$TQTDIR/bin:$PATH
LD_LIBRARY_PATH=$TDEDIR/lib:$LD_LIBRARY_PATH
export TDEDIRS PATH LD_LIBRARY_PATH
</programlisting>
@@ -264,13 +264,13 @@ export TDEDIRS PATH LD_LIBRARY_PATH
If you are building the qt-copy module, add instead:
<programlisting>
-QTDIR=(path to qtdir)
+TQTDIR=(path to qtdir)
TDEDIR=(path to tdedir)
TDEDIRS=$TDEDIR
-PATH=$TDEDIR/bin:$QTDIR/bin:$PATH
-MANPATH=$QTDIR/doc/man:$MANPATH
-LD_LIBRARY_PATH=$TDEDIR/lib:$QTDIR/lib:$LD_LIBRARY_PATH
-export QTDIR TDEDIRS PATH MANPATH LD_LIBRARY_PATH
+PATH=$TDEDIR/bin:$TQTDIR/bin:$PATH
+MANPATH=$TQTDIR/doc/man:$MANPATH
+LD_LIBRARY_PATH=$TDEDIR/lib:$TQTDIR/lib:$LD_LIBRARY_PATH
+export TQTDIR TDEDIRS PATH MANPATH LD_LIBRARY_PATH
</programlisting>
</para>
@@ -420,7 +420,7 @@ source tree, you can force a rebuild of a module by creating a file called
<listitem><para>
You can specify various environment values to be used during the build,
-including <envar>TDEDIR</envar>, <envar>QTDIR</envar>, <envar>DO_NOT_COMPILE</envar>,
+including <envar>TDEDIR</envar>, <envar>TQTDIR</envar>, <envar>DO_NOT_COMPILE</envar>,
and <envar>CXXFLAGS</envar>.
</para></listitem>
@@ -624,7 +624,7 @@ You can't override this setting in a module option. The default value is
<filename class="directory">/bin:/usr/bin:/usr/local/bin:/usr/X11R6/bin</filename>. This environment
variable should include the colon-separated paths of your development
toolchain. The paths <filename class="directory">$TDEDIR/bin</filename> and
-<filename class="directory">$QTDIR/bin</filename> are automatically added. You
+<filename class="directory">$TQTDIR/bin</filename> are automatically added. You
may use the tilde (~) for any paths you add using this option.</para>
</entry>
</row>
@@ -829,7 +829,7 @@ linkend="conf-make-install-prefix">make-install-prefix</link> option as well.</e
<entry>Set this option to set the environment variable LD_LIBRARY_PATH while
building. You can't override this setting in a module option. The default
value is blank, but the paths <filename class="directory">$TDEDIR/lib</filename> and
-<filename class="directory">$QTDIR/lib</filename> are automatically
+<filename class="directory">$TQTDIR/lib</filename> are automatically
added. You may use the tilde (~) for any paths you add using this option.
</entry>
</row>
@@ -930,7 +930,7 @@ can't figure out what you mean using <link linkend="conf-branch">branch</link>.
<row id="conf-qtdir">
<entry>qtdir</entry>
<entry>Can't be overridden</entry>
-<entry>Set this option to set the environment variable QTDIR while building.
+<entry>Set this option to set the environment variable TQTDIR while building.
You can't override this setting in a module option. If you don't specify
this option, it defaults to
<filename class="directory"><varname>$(source-dir)</varname>/build/qt-copy</filename>,
@@ -1024,7 +1024,7 @@ instead, which works from the release tarballs.</para>
qt-copy. Set this option to <quote>true</quote> to enable the script's
<emphasis>experimental</emphasis> srcdir != builddir mode. When enabled,
&tdesvn-build; will copy the qt-copy source module to the build directory,
-and perform builds from there. That means your QTDIR environment variable
+and perform builds from there. That means your TQTDIR environment variable
should be set to
<filename class="directory">$(qt-copy-build-dir)/qt-copy/lib</filename>
instead. You should also change your <link linkend="conf-qtdir">qtdir</link>
diff --git a/scripts/kde-build b/scripts/kde-build
index de6f6c3b..666e763e 100755
--- a/scripts/kde-build
+++ b/scripts/kde-build
@@ -51,7 +51,7 @@ err_install_fail="5"
#
err_inv_kdesrcdir="6"
-# The $QTDIR variable wasn't set, points to a non-existant directory or
+# The $TQTDIR variable wasn't set, points to a non-existant directory or
# doesn't contain a bin/, lib/, or include/ subdirectory.
#
err_inv_qtdir="7"
@@ -370,7 +370,7 @@ if [ "$dousage" -eq 1 ]; then
fi
# Expand ~
-QTDIR=`echo "$QTDIR" | sed -e "s,^\~/,$HOME/,"`
+TQTDIR=`echo "$TQTDIR" | sed -e "s,^\~/,$HOME/,"`
KDESRCDIR=`echo "$KDESRCDIR" | sed -e "s,^\~/,$HOME/,"`
KDEBUILDDIR=`echo "$KDEBUILDDIR" |sed -e "s,^\~/,$HOME/,"`
TDEDIRS=`echo "$TDEDIRS" |sed -e "s,^\~/,$HOME/,"`
@@ -378,9 +378,9 @@ KDELOGDIR=`echo "$KDELOGDIR" |sed -e "s,^\~/,$HOME/,"`
# Make sure some paths are according to the rc file. Note that there are AFAIK
# UNIX flavors which don't support LD_LIBRARY_PATH
-PATH=$QTDIR/bin:$TDEDIRS/bin:$PATH
-MANPATH=$QTDIR/doc/man:$MANPATH
-LD_LIBRARY_PATH=$TDEDIRS/lib:$QTDIR/lib:$LD_LIBRARY_PATH
+PATH=$TQTDIR/bin:$TDEDIRS/bin:$PATH
+MANPATH=$TQTDIR/doc/man:$MANPATH
+LD_LIBRARY_PATH=$TDEDIRS/lib:$TQTDIR/lib:$LD_LIBRARY_PATH
if [ -n "$USE_UNSERMAKE" ]; then
if [ -n "$MAKE" ]; then
@@ -445,7 +445,7 @@ fi
if [ ! -d "$KDESRCDIR" ]; then
echo "ERROR: Invalid source directory specified!"; exit $err_inv_kdesrcdir
fi
-if [ ! -d "$QTDIR" -o ! -d "$QTDIR/lib" -o ! -d "$QTDIR/bin" -o ! -d "$QTDIR/include" ]; then
+if [ ! -d "$TQTDIR" -o ! -d "$TQTDIR/lib" -o ! -d "$TQTDIR/bin" -o ! -d "$TQTDIR/include" ]; then
echo "ERROR: Invalid Qt directory specified!"; exit $err_inv_qtdir
fi
@@ -678,9 +678,9 @@ for module in $modules; do
echo -n " Configuring..."
set_title "Configuring module $module..."
if [ -n "$KDEBUILDDIR" ]; then
- cmd_configure="$KDESRCDIR/$module/configure $CONFIGUREFLAGS --with-qt-dir=$QTDIR"
+ cmd_configure="$KDESRCDIR/$module/configure $CONFIGUREFLAGS --with-qt-dir=$TQTDIR"
else
- cmd_configure="./configure $CONFIGUREFLAGS --with-qt-dir=$QTDIR"
+ cmd_configure="./configure $CONFIGUREFLAGS --with-qt-dir=$TQTDIR"
fi
if echo $CONFIGUREFLAGS | grep -v -- "--prefix=" 2>/dev/null >/dev/null; then
cmd_configure="$cmd_configure --prefix=$TDEDIRS"
diff --git a/scripts/kde-buildrc b/scripts/kde-buildrc
index 24553e01..6d83a924 100644
--- a/scripts/kde-buildrc
+++ b/scripts/kde-buildrc
@@ -18,7 +18,7 @@ TDEDIRS="/opt/kde"
# Where is your Qt 3.3.x?
#
-QTDIR="/usr/lib/qt3"
+TQTDIR="/usr/lib/qt3"
# Should kppp be used to connect to the internet?
#
diff --git a/scripts/kde-devel-vim.vim b/scripts/kde-devel-vim.vim
index d59069ed..f58164af 100644
--- a/scripts/kde-devel-vim.vim
+++ b/scripts/kde-devel-vim.vim
@@ -13,8 +13,8 @@ set suffixes+=.lo,.o,.moc,.la,.closure,.loT
" Search for headers here
set path=.,/usr/include,/usr/local/include,
-if $QTDIR != ''
- let &path = &path . $QTDIR . '/include/,'
+if $TQTDIR != ''
+ let &path = &path . $TQTDIR . '/include/,'
endif
if $TDEDIR != ''
let &path = &path . $TDEDIR . '/include/,'
diff --git a/scripts/qtdoc b/scripts/qtdoc
index 6250f7a9..f20fe2b2 100755
--- a/scripts/qtdoc
+++ b/scripts/qtdoc
@@ -1,7 +1,7 @@
#!/bin/sh
-if [ -z "$QTDIR" ]; then
- QTDIR=/usr/share/qt3
+if [ -z "$TQTDIR" ]; then
+ TQTDIR=/usr/share/qt3
fi
# Run from command line, to open a qt help page in kfm/konqueror
@@ -10,8 +10,8 @@ fi
if [ $# = 1 ]; then
fname=`echo $1 | tr '[A-Z]' '[a-z]'`
- if [ -f $QTDIR/doc/html/$fname.html ]; then
- tdeinit_wrapper kfmclient openProfile webbrowsing file:$QTDIR/doc/html/$fname.html
+ if [ -f $TQTDIR/doc/html/$fname.html ]; then
+ tdeinit_wrapper kfmclient openProfile webbrowsing file:$TQTDIR/doc/html/$fname.html
else
if [ -f /usr/doc/qt2/html/$fname.html ]; then
tdeinit_wrapper kfmclient openProfile webbrowsing file:/usr/doc/qt2/html/$fname.html
@@ -20,5 +20,5 @@ if [ $# = 1 ]; then
fi
fi
else
- kfmclient openURL file:$QTDIR/doc/html/index.html
+ kfmclient openURL file:$TQTDIR/doc/html/index.html
fi
diff --git a/scripts/tdesvn-build b/scripts/tdesvn-build
index ec48e3e9..525909c1 100755
--- a/scripts/tdesvn-build
+++ b/scripts/tdesvn-build
@@ -3434,7 +3434,7 @@ sub update_module_environment
# Set up the children's environment. We use setenv since it
# won't set an environment variable to nothing. (e.g, setting
- # QTDIR to a blank string might confuse Qt or KDE.
+ # TQTDIR to a blank string might confuse Qt or KDE.
# Remove leading and trailing colons, just in case.
# Also remove more than one colon.
@@ -3462,7 +3462,7 @@ sub update_module_environment
setenv ('LD_LIBRARY_PATH', $libdir);
setenv ('PATH', $path);
setenv ('TDEDIR', $tdedir);
- setenv ('QTDIR', $qtdir);
+ setenv ('TQTDIR', $qtdir);
# Qt has several defines of its own. Special case qt-copy for this
# reason.
@@ -3579,7 +3579,7 @@ sub build_module
$qtpath =~ s/$ENV{HOME}/~/;
warning <<EOF;
-b[y[!!] You're building qt-copy, but QTDIR isn't set to use qt-copy!
+b[y[!!] You're building qt-copy, but TQTDIR isn't set to use qt-copy!
b[y[!!] Please set your qtdir variable in the global section of your
b[y[!!] $rcfile to g[$qtpath]
diff --git a/scripts/kde-emacs/kde-emacs-utils.el b/scripts/kde-emacs/kde-emacs-utils.el
index 37cc8977..d983ae30 100644
--- a/scripts/kde-emacs/kde-emacs-utils.el
+++ b/scripts/kde-emacs/kde-emacs-utils.el
@@ -865,14 +865,14 @@ This function does not do any hidden buffer changes."
(defun qt-open-header ()
"Open the Qt header file for the class under point"
(interactive)
- (let* ((qtinc (concat (getenv "QTDIR") "/include/"))
+ (let* ((qtinc (concat (getenv "TQTDIR") "/include/"))
(class (thing-at-point 'word))
(f nil)
(file nil)
(files nil)
)
(save-excursion
; The Qt3 case: the includes are directly in $QTDIR/include/, lowercased
(set f (concat qtinc (downcase class) ".h" ))
(if (file-readable-p f)
(set file f)
@@ -880,7 +880,7 @@ This function does not do any hidden buffer changes."
(set f (concat qtinc (downcase class) "_qws.h" ))
(if (file-readable-p f)
(set file f)
; The Qt4 case: the includes are in $QTDIR/include/QSomething/, in original case
(set files (directory-files qtinc t nil "dirsonly"))
(dolist (f files nil)
(if (file-readable-p (concat f "/" class) )
@@ -865,14 +865,14 @@ This function does not do any hidden buffer changes."
)
(save-excursion
- ; The Qt3 case: the includes are directly in $QTDIR/include/, lowercased
+ ; The Qt3 case: the includes are directly in $TQTDIR/include/, lowercased
(set f (concat qtinc (downcase class) ".h" ))
(if (file-readable-p f)
@@ -880,7 +880,7 @@ This function does not do any hidden buffer changes."
(if (file-readable-p f)
(set file f)
- ; The Qt4 case: the includes are in $QTDIR/include/QSomething/, in original case
+ ; The Qt4 case: the includes are in $TQTDIR/include/QSomething/, in original case
(set files (directory-files qtinc t nil "dirsonly"))
(dolist (f files nil)